==> kubernetes-model-admissionregistration-5.0.0-sources.jar: annotations/io/fabric8/kubernetes/api/model/authentication/TokenReviewSpecFluent.java <==
package io.fabric8.kubernetes.api.model.authentication;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import com.fasterxml.jackson.annotation.JsonInclude;
import java.util.ArrayList;
import java.lang.String;
import java.util.function.Predicate;
import java.lang.StringBuffer;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

public interface TokenReviewSpecFluent<A extends TokenReviewSpecFluent<A>> extends Fluent<A> {


    public A addToAudiences(int index,String item);
    public A setToAudiences(int index,String item);
    public A addToAudiences(String... items);
    public A addAllToAudiences(Collection<String> items);
    public A removeFromAudiences(String... items);
    public A removeAllFromAudiences(Collection<String> items);
    public List<String> getAudiences();
    public String getAudience(int index);
    public String getFirstAudience();
    public String getLastAudience();
    public String getMatchingAudience(Predicate<String> predicate);
    public Boolean hasMatchingAudience(Predicate<String> predicate);
    public A withAudiences(List<String> audiences);
    public A withAudiences(String... audiences);
    public Boolean hasAudiences();
    public A addNewAudience(String arg1);
    public A addNewAudience(StringBuilder arg1);
    public A addNewAudience(StringBuffer arg1);
    public String getToken();
    public A withToken(String token);
    public Boolean hasToken();
    public A withNewToken(String arg1);
    public A withNewToken(StringBuilder arg1);
    public A withNewToken(StringBuffer arg1);
}

==> kubernetes-model-admissionregistration-5.3.1-sources.jar: annotations/io/fabric8/kubernetes/api/model/authentication/TokenReviewSpecFluent.java <==
package io.fabric8.kubernetes.api.model.authentication;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import com.fasterxml.jackson.annotation.JsonInclude;
import java.util.ArrayList;
import java.lang.String;
import java.util.function.Predicate;
import java.lang.StringBuffer;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

public interface TokenReviewSpecFluent<A extends TokenReviewSpecFluent<A>> extends io.fabric8.kubernetes.api.builder.Fluent<A> {


    public A addToAudiences(int index,String item);
    public A setToAudiences(int index,String item);
    public A addToAudiences(String... items);
    public A addAllToAudiences(Collection<String> items);
    public A removeFromAudiences(String... items);
    public A removeAllFromAudiences(Collection<String> items);
    public List<String> getAudiences();
    public String getAudience(int index);
    public String getFirstAudience();
    public String getLastAudience();
    public String getMatchingAudience(Predicate<String> predicate);
    public Boolean hasMatchingAudience(Predicate<String> predicate);
    public A withAudiences(List<String> audiences);
    public A withAudiences(String... audiences);
    public Boolean hasAudiences();
    public A addNewAudience(StringBuilder arg1);
    public A addNewAudience(int[] arg1,int arg2,int arg3);
    public A addNewAudience(char[] arg1);
    public A addNewAudience(StringBuffer arg1);
    public A addNewAudience(byte[] arg1,int arg2);
    public A addNewAudience(byte[] arg1);
    public A addNewAudience(char[] arg1,int arg2,int arg3);
    public A addNewAudience(byte[] arg1,int arg2,int arg3);
    public A addNewAudience(byte[] arg1,int arg2,int arg3,int arg4);
    public A addNewAudience(String arg1);
    public String getToken();
    public A withToken(String token);
    public Boolean hasToken();
    public A withNewToken(StringBuilder arg1);
    public A withNewToken(int[] arg1,int arg2,int arg3);
    public A withNewToken(char[] arg1);
    public A withNewToken(StringBuffer arg1);
    public A withNewToken(byte[] arg1,int arg2);
    public A withNewToken(byte[] arg1);
    public A withNewToken(char[] arg1,int arg2,int arg3);
    public A withNewToken(byte[] arg1,int arg2,int arg3);
    public A withNewToken(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewToken(String arg1);
}
